Установка — m3-mutex documentation

### Navigation

- index
- next |
- previous |
- m3-mutex documentation »

# Установка

## Необходимые библиотеки и другие модули

Для работы m3-mutex необходимы следующие модули:

- django
- south
- m3_legacy

## Установка и настройка

Для подключения m3-mutex к django-проекту необходимо добавить в список установленных приложений:

    INSTALLED_APPS = {
            ...,
            'm3_mutex',
            ...
    }

### Navigation

- index
- next |
- previous |
- m3-mutex documentation »